@@ -15,7 +15,7 @@ use List::MoreUtils qw( all zip );
 use Array::Transpose;
 use List::Util::WeightedChoice qw( choose_weighted );
 
-our $VERSION = '0.1902';
+our $VERSION = '0.1903';
 
 
 
@@ -445,12 +445,12 @@ sub nash
 
 sub play
 {
-    my ( $self, $strategies ) = @_;
+    my ( $self, %strategies ) = @_;
 
     my $play;
 
     # Allow for alternate strategies
-    $self->{$_} = $strategies->{$_} for keys %$strategies;
+    $self->{$_} = $strategies{$_} for keys %strategies;
 
     my $player  = 1;
     my $keys    = [ sort { $a <=> $b } keys %{ $self->{$player} } ];
@@ -483,7 +483,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.1902
+version 0.1903
 
 =head1 SYNOPSIS
 
@@ -630,10 +630,10 @@ Identify the Nash equilibria in a non-zero-sum game.
 Given payoff pair C<(a,b)>, B<a> is maximum for its column and B<b> is maximum
 for its row.
 
-=head2 play
+=head2 play()
 
  $u = $g->play();
- $u = $g->play(\%strategies);
+ $u = $g->play(%strategies);
 
 Return a single outcome for a zero-sum game or a pair for a non-zero-sum game.
 
